@@ -11,7 +11,6 @@ colorama.init(autoreset=True)
 
 def main():
     arg = sys.argv
-    print(arg)
 
     if len(arg) == 1:
         print(f'{colorama.Fore.BLUE}Welcome to Backpack (bkpk)!')
@@ -26,11 +25,7 @@ def main():
 
     if arg[-1].endswith(models.FILE_EXTENSION):
         unpack.load(arg[-1])
-        print(f'{colorama.Fore.GREEN}BKPK · Unpacking successful!')
+        print(f'{colorama.Fore.GREEN}🎒 Unpacking successful!')
     else:
         pack.save(arg[-1])
-        print(f'{colorama.Fore.GREEN}BKPK · Unpacking successful!')
-
-    print('BKPK · Done')
-
-main()
\ No newline at end of file
+        print(f'{colorama.Fore.GREEN}🎒 Packing successful!')
